package com.dahe.gldriver.ui.account.authperson

import android.os.Bundle
import android.view.View
import com.dahe.gldriver.R
import com.dahe.gldriver.base.AppConfig
import com.dahe.gldriver.base.AppConfig.USER_DETAIL
import com.dahe.gldriver.bean.OcrPersonBean
import com.dahe.gldriver.bean.UpPersonInfoBean
import com.dahe.gldriver.databinding.ActivityAuthPersonBinding
import com.dahe.gldriver.net.BaseObserver
import com.dahe.gldriver.net.DataManager
import com.dahe.gldriver.net.RxHttpCallBack
import com.dahe.gldriver.utils.OcrUtils
import com.dahe.glex.bean.UserDetail
import com.dahe.mylibrary.base.BaseActivity
import com.dahe.mylibrary.net.CommonResponseBean
import com.dahe.mylibrary.utils.ActivityUtils
import com.dahe.mylibrary.utils.ImageLoader
import com.dahe.mylibrary.utils.PickerUtils
import com.dahe.mylibrary.utils.PopsUtils
import com.dahe.mylibrary.utils.TimeUtil
import com.google.gson.Gson
import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers
import io.reactivex.rxjava3.schedulers.Schedulers
import okhttp3.MediaType.Companion.toMediaTypeOrNull
import okhttp3.MultipartBody
import okhttp3.RequestBody.Companion.asRequestBody
import java.io.File

/**
 * @ClassName AuthRoleActivity
 * @Author 用户
 * @Date 2024/1/25 11:15
 * @Description 身份证认证-编辑
 */
class EditPersonActivity : BaseActivity<ActivityAuthPersonBinding>() {

    var perInfoBean: UserDetail = UserDetail()
    override fun initView(savedInstanceState: Bundle?) {
        setStatusBarColor(R.color.white)
        setTitleBar("实名认证", true)
        binding.run {
            btnOk.text = "确定"

            var inBinding = this
            btnOk.setOnClickListener {

                perInfoBean.run {
                    idcardNo = inBinding.etId.text.toString()
                    idcardName = inBinding.etName.text.toString()
                    idcardEffectiveStart = inBinding.tvStart.text.toString()
                    idcardEffectiveEnd = inBinding.tvEnd.text.toString()
                }


                DataManager.getInstance().reUpDriverIdCard(perInfoBean)
                    .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread())
                    .subscribe(BaseObserver(mContext, object : RxHttpCallBack<Any>() {
                        override fun onSuccess(t: CommonResponseBean<Any>) {
                            super.onSuccess(t)
                            showToast("修改成功")
                            setResult(RESULT_OK)
                            finish()
                        }
                    }))


            }
            tvStart.run {
                setOnClickListener {
                    PickerUtils.getInstance()
                        .showDate(this@EditPersonActivity, "有效起始日期") { date ->
                            this.text = date
                        }
                }
            }
            tvEnd.run {
                setOnClickListener {
                    PickerUtils.getInstance()
                        .showDate(this@EditPersonActivity, "有效结束日期") { date ->
                            this.text = date
                        }
                }
            }

            ivFront.setOnClickListener {
                OcrUtils.getInstance()
                    .ocrPerson(mContext, this@EditPersonActivity) { picPath, result ->
                        ImageLoader.getInstance()
                            .loadRoundImage(mContext, picPath.locPic, 12, ivFront)
                        perInfoBean.idcardFrontUrl = picPath.picPath
                        result?.data?.face?.data.let {
                            it?.run {
                                perInfoBean.run {
                                    idcardNo = idNumber
                                    idcardName = name
                                    idcardAddress = address
                                    idcardEthnicity = ethnicity
                                    idcardSex = if (sex == "男") "0" else "1"
                                }
                            }
                            binding.run {
                                etName.setText(it?.name)
                                etId.setText(it?.idNumber)
                            }
                        }
                    }
            }

            ivBack.setOnClickListener {
                OcrUtils.getInstance()
                    .ocrPerson(mContext, this@EditPersonActivity) { picPath, result ->
                        ImageLoader.getInstance()
                            .loadRoundImage(mContext, picPath.locPic, 12, ivBack)
                        result?.data?.back?.let {
                            if (it.data.validPeriod?.contains("-") == true) {
                                val split = it.data.validPeriod.split("-")
                                binding.run {
                                    tvStart.text =
                                        TimeUtil.changeDateFormat(split[0])
                                    tvEnd.text =
                                        if (split.size == 2) TimeUtil.changeDateFormat(
                                            split[1]
                                        ) else ""
                                }
                            }
                        }

                    }
            }
        }


    }

    override fun initDate() {
        DataManager.getInstance().getUserDetail()
            .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread())
            .subscribe(BaseObserver(mContext, object : RxHttpCallBack<UserDetail>() {
                override fun onSuccess(t: CommonResponseBean<UserDetail>) {
                    super.onSuccess(t)
                    perInfoBean = t.data
                    var isOnlyShow =
                        intent.extras?.getBoolean(AppConfig.IS_ONLY_SHOW, false) == true
                    if (isOnlyShow) {
                        binding.run {
                            llBtn.visibility = View.GONE
                            etName.isEnabled = false
                            etId.isEnabled = false
                            tvStart.isEnabled = false
                            tvEnd.isEnabled = false
                            ivFront.isEnabled = false
                            ivBack.isEnabled = false
                        }
                    }
                    binding.run {
                        etName.setText(perInfoBean.idcardName)
                        etId.setText(perInfoBean.idcardNo)
                        tvStart.text = perInfoBean.idcardEffectiveStart
                        tvEnd.text = perInfoBean.idcardEffectiveEnd
                        ImageLoader.getInstance()
                            .loadRoundImage(mContext, perInfoBean.idcardFrontUrl, 12, ivFront)
                        ImageLoader.getInstance()
                            .loadRoundImage(mContext, perInfoBean.idcardBackUrl, 12, ivBack)
                    }
                }
            }))


    }
}