package com.dahe.gldriver.ui.account.authperson

import android.os.Bundle
import com.dahe.gldriver.R
import com.dahe.gldriver.base.AppConfig
import com.dahe.gldriver.bean.UpQualiInfoBean
import com.dahe.gldriver.databinding.ActivityAuthQualificationBinding
import com.dahe.gldriver.net.BaseObserver
import com.dahe.gldriver.net.DataManager
import com.dahe.gldriver.net.RxHttpCallBack
import com.dahe.gldriver.oss.OssServiceUtil
import com.dahe.gldriver.utils.OcrUtils
import com.dahe.glex.bean.UserDetail
import com.dahe.mylibrary.utils.PickerUtils
import com.dahe.mylibrary.base.BaseActivity
import com.dahe.mylibrary.net.CommonResponseBean
import com.dahe.mylibrary.utils.ActivityUtils
import com.dahe.mylibrary.utils.ImageLoader
import com.dahe.mylibrary.utils.PopsUtils
import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers
import io.reactivex.rxjava3.schedulers.Schedulers

/**
 * @ClassName AuthQualificationActivity
 * @Author john
 * @Date 2024/1/25 15:20
 * @Description 从业资格证认证-编辑
 */
class EditQualificationActivity : BaseActivity<ActivityAuthQualificationBinding>() {

    var upQuaInfo = UserDetail()
    override fun initView(savedInstanceState: Bundle?) {
        setStatusBarColor(R.color.white)
        setTitleBar("实名认证", true)
        binding.btnOk.setOnClickListener {
            subMit()
        }

        binding.run {
            btnOk.text = "确定"
            tvDate.run {
                setOnClickListener {
                    PickerUtils.getInstance()
                        .showDateSim(
                            this@EditQualificationActivity,
                            "选择有效期至"
                        ) { date ->
                            this.text = date
                        }
                }
            }

            ivFront.setOnClickListener {
                OcrUtils.getInstance()
                    .noOcrUpPic(mContext, this@EditQualificationActivity) { picPath, _ ->
                        ImageLoader.getInstance()
                            .loadRoundImage(mContext, picPath.locPic, 12, ivFront)
                        upQuaInfo.qualificationCertificatePhotoUrl = picPath.picPath
                    }
            }
        }
    }

    override fun initDate() {
        DataManager.getInstance().getUserDetail()
            .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread())
            .subscribe(BaseObserver(mContext, object : RxHttpCallBack<UserDetail>() {
                override fun onSuccess(t: CommonResponseBean<UserDetail>) {
                    super.onSuccess(t)
                    upQuaInfo = t.data
                    binding.run {

                        var isOnlyShow =
                            intent.extras?.getBoolean(AppConfig.IS_ONLY_SHOW, false) == true
                        if (isOnlyShow) {
                            tvDate.isEnabled = false
                            etId.isEnabled = false
                            ivFront.isEnabled = false
                        }

                        tvDate.setText(upQuaInfo.qualificationCertificateEffectiveEnd)
                        etId.setText(upQuaInfo.qualificationCertificateNo)

                        ImageLoader.getInstance()
                            .loadRoundImage(
                                mContext,
                                upQuaInfo.qualificationCertificatePhotoUrl,
                                12,
                                ivFront
                            )
                    }
                }
            }))
    }

    private fun subMit() {

        upQuaInfo.run {
            qualificationCertificateNo = binding.etId.text.toString()
            qualificationCertificateEffectiveEnd = binding.tvDate.text.toString()


            if (qualificationCertificateNo.isNullOrEmpty() || qualificationCertificateEffectiveEnd.isNullOrEmpty()) {
                showToast("请完善信息")
                return@run
            }

            DataManager.getInstance().reUpDriverQualificationCertificate(upQuaInfo)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(BaseObserver(mContext, object : RxHttpCallBack<Any>() {
                    override fun onSuccess(t: CommonResponseBean<Any>) {
                        super.onSuccess(t)
                        showToast("修改成功")
                        setResult(RESULT_OK)
                        finish()
                    }
                }))
        }
    }
}