package com.dahe.gldriver.ui.account.authperson

import android.os.Bundle
import android.view.View
import com.dahe.gldriver.R
import com.dahe.gldriver.base.AppConfig
import com.dahe.gldriver.bean.UpDrivingInfoBean
import com.dahe.gldriver.bean.UpQualiInfoBean
import com.dahe.gldriver.bean.UpRoadInfoBean
import com.dahe.gldriver.databinding.ActivityAuthRoadBinding
import com.dahe.gldriver.net.BaseObserver
import com.dahe.gldriver.net.DataManager
import com.dahe.gldriver.net.RxHttpCallBack
import com.dahe.gldriver.oss.OssServiceUtil
import com.dahe.gldriver.ui.account.AuthSuccActivity
import com.dahe.gldriver.ui.account.SelectRoleActivity
import com.dahe.gldriver.utils.OcrUtils
import com.dahe.mylibrary.base.BaseActivity
import com.dahe.mylibrary.net.CommonResponseBean
import com.dahe.mylibrary.utils.ActivityUtils
import com.dahe.mylibrary.utils.ImageLoader
import com.dahe.mylibrary.utils.PickerUtils
import com.dahe.mylibrary.utils.PopsUtils
import com.github.gzuliyujiang.wheelpicker.contract.OnDatePickedListener
import com.mobile.auth.gatewayauth.model.popsdkconfig.UploadData
import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers
import io.reactivex.rxjava3.schedulers.Schedulers

/**
 * @ClassName AuthRoadActivity
 * @Author john
 * @Date 2024/1/25 16:02
 * @Description 道路运输许可证认证-编辑
 */
class EditRoadActivity : BaseActivity<ActivityAuthRoadBinding>() {

    var upRoad = UpDrivingInfoBean()

    override fun initView(savedInstanceState: Bundle?) {
        setStatusBarColor(R.color.white)
        setTitleBar("实名认证", true)
        binding.run {
            btnOk.text = "确定"
            btnOk.setOnClickListener {
                subMit()
            }

            tvDate.setOnClickListener {
                PickerUtils.getInstance().showDateSim(this@EditRoadActivity) {
                    upRoad.roadLicenseValidity = it
                    binding.tvDate.text = it
                }
            }
            ivFront.setOnClickListener {
                OcrUtils.getInstance()
                    .noOcrUpPic(mContext, this@EditRoadActivity) { picPath, ocrResult ->
                        ImageLoader.getInstance()
                            .loadRoundImage(mContext, picPath.locPic, 12, ivFront)
                        upRoad.roadLicensePhotoUrl = picPath.picPath
                    }
            }
        }
    }

    override fun initDate() {
        var carId = intent.extras?.getString(AppConfig.CAR_ID).toString()
        DataManager.getInstance().getCarByCarVehicleNum(carId)
            .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread())
            .subscribe(BaseObserver(mContext, object : RxHttpCallBack<UpDrivingInfoBean>() {
                override fun onSuccess(t: CommonResponseBean<UpDrivingInfoBean>) {
                    super.onSuccess(t)
                    initViewByData(t.data)
                }
            }))
    }

    private fun initViewByData(data: UpDrivingInfoBean) {
        upRoad = data
        var isOnlyShow =
            intent.extras?.getBoolean(AppConfig.IS_ONLY_SHOW, false) == true
        if (isOnlyShow) {
            binding.run {
                llBtn.visibility = View.GONE
                etID.isEnabled = false
                tvDate.isEnabled = false
                ivFront.isEnabled = false
            }
        }
        binding.run {
            ImageLoader.getInstance()
                .loadRoundImage(mContext, data.licenseFaceUrl, 12, ivFront)

            etID.setText(data.roadLicense)
            tvDate.text = data.roadLicenseValidity
        }


    }

    private fun subMit() {
        upRoad.run {
            roadLicense = binding.etID.text.trim().toString()
            roadLicenseValidity = binding.tvDate.text.toString()

            if (upRoad.roadLicense.isNullOrEmpty() || upRoad.roadLicenseValidity.isNullOrEmpty() || upRoad.roadLicensePhotoUrl.isNullOrEmpty()) {
                showToast("请完善信息")
                return
            }

            DataManager.getInstance().editCar(upRoad)
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(BaseObserver(mContext, object : RxHttpCallBack<UpDrivingInfoBean>() {
                    override fun onSuccess(t: CommonResponseBean<UpDrivingInfoBean>) {
                        super.onSuccess(t)
                        showToast("修改成功")
                        setResult(RESULT_OK)
                        finish()
                    }
                }))
        }
    }
}