package com.dahe.gldriver.ui.home.activity

import android.graphics.Color
import android.os.Bundle
import android.widget.LinearLayout
import androidx.recyclerview.widget.GridLayoutManager
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.amap.api.maps.AMap
import com.amap.api.services.core.LatLonPoint
import com.amap.api.services.core.PoiItem
import com.amap.api.services.poisearch.PoiResult
import com.amap.api.services.poisearch.PoiSearch
import com.dahe.gldriver.R
import com.dahe.gldriver.adapter.BusinessAdapter
import com.dahe.gldriver.adapter.BusinessListAdapter
import com.dahe.gldriver.databinding.ActivityBusinessBinding
import com.dahe.gldriver.utils.GDLocationUtils
import com.dahe.mylibrary.base.BaseActivity
import com.dahe.mylibrary.recycleviewswipe.RecycleViewDivider
import com.dahe.mylibrary.utils.ConvertUtils
import com.dahe.mylibrary.utils.LoadingUtils
import com.dahe.mylibrary.utils.ToastUtils
import com.dahe.mylibrary.weight.FullyGridLayoutManager
import com.luck.picture.lib.decoration.GridSpacingItemDecoration
import com.luck.picture.lib.utils.DensityUtil

/**
 * @ClassName BusinessActivity
 * @Author john
 * @Date 2024/3/25 11:24
 * @Description TODO
 */
class BusinessActivity : BaseActivity<ActivityBusinessBinding>(), PoiSearch.OnPoiSearchListener {
    var listType: List<Model> = arrayListOf(
        Model("餐饮", R.drawable.icon_canguan),
        Model("住宿", R.drawable.icon_jiudian),
        Model("商店", R.drawable.icon_shangdian),
        Model("加油站", R.drawable.icon_jiayouzhan),
        Model("汽车维修", R.drawable.icon_xiuche)
    )

    private val type = listType[0].type_name

    private var mAMap: AMap? = null
    private var query: PoiSearch.Query? = null
    private var currLoca: LatLonPoint? = null
    var adapterList: BusinessListAdapter? = null

    override fun initView(savedInstanceState: Bundle?) {
        setStatusBarColor(R.color.white)
        setTitleBar("司机之家", true)

        binding.run {
            businessType.run {
                layoutManager =
                    FullyGridLayoutManager(mContext, 4, GridLayoutManager.VERTICAL, false)
                addItemDecoration(
                    GridSpacingItemDecoration(
                        4,
                        DensityUtil.dip2px(mContext, 8f), false
                    )
                )
                adapter = BusinessAdapter().apply {
                    submitList(listType)
                    setOnItemClickListener { _, _, postion ->
                        changeType(listType[postion].type_name)
                    }
                }

            }

            adapterList = businessList.run {
                layoutManager = LinearLayoutManager(mContext, RecyclerView.VERTICAL, false)
                addItemDecoration(
                    RecycleViewDivider(
                        LinearLayout.VERTICAL,
                        ConvertUtils.dp2px(10.0f),
                        Color.TRANSPARENT
                    )
                )

                adapter = BusinessListAdapter()
                adapter as BusinessListAdapter
            }

        }

        LoadingUtils.instance.showLoading(this, "定位中...")
        GDLocationUtils.instance.getLocation(mContext) {
            runOnUiThread {
                LoadingUtils.instance.dissLoading()
                if (it.getErrorCode() == 0) {
                    try {
                        binding.address.text = it.address
                        currLoca = LatLonPoint(it.getLatitude(), it.getLongitude())
                        val poiSearch = PoiSearch(this, query)
                        poiSearch.setOnPoiSearchListener(this)
                        poiSearch.bound = PoiSearch.SearchBound(currLoca, 5000, true) //
                        // 设置搜索区域为以lp点为圆心，其周围5000米范围
                        poiSearch.searchPOIAsyn() // 异步搜索
                    } catch (e: java.lang.Exception) {
                        e.printStackTrace()
                    }

                } else {
                    showToast("定位失败,请检查定位权限是否开启")
                }
            }
        }
        changeType(type)
    }

    override fun initDate() {
    }

    private fun changeType(type: String) {
        query = PoiSearch.Query(type, "", "")
        query?.setExtensions("all")
        query?.setPageSize(20) // 设置每页最多返回多少条poiitem
        query?.setPageNum(0) // 设置查第一页
        if (currLoca != null) {
            try {
                val poiSearch = PoiSearch(this, query)
                poiSearch.setOnPoiSearchListener(this)
                poiSearch.bound = PoiSearch.SearchBound(currLoca, 5000, true) //
                // 设置搜索区域为以lp点为圆心，其周围5000米范围
                poiSearch.searchPOIAsyn() // 异步搜索
            } catch (e: Exception) {
                e.printStackTrace()
            }
        }
    }

    class Model(var type_name: String, var type_img: Int)

    override fun onPoiSearched(p0: PoiResult?, p1: Int) {
        if (p0 != null && p0.getQuery() != null) { // 搜索poi的结果
            var poiItems = p0.getPois() // 当搜索不到poiitem数据时，会返回含有搜索关键字的城市信息
            if (poiItems != null && poiItems.size > 0) {
                adapterList?.submitList(poiItems)
            } else {
                ToastUtils.showToast(mContext, "对不起，没有搜索到相关数据!")
            }
        } else {
            ToastUtils.showToast(mContext, "对不起，没有搜索到相关数据!")
        }
    }

    override fun onPoiItemSearched(p0: PoiItem?, p1: Int) {
    }


}