package com.dahe.gldriver.ui.mine.activity

import android.content.Intent
import android.os.Bundle
import android.view.View
import com.dahe.gldriver.base.AppConfig
import com.dahe.gldriver.bean.CarDetail
import com.dahe.gldriver.databinding.ActivityCarDetailBinding
import com.dahe.gldriver.databinding.ActivityDriverTeamDetailBinding
import com.dahe.gldriver.net.BaseObserver
import com.dahe.gldriver.net.DataManager
import com.dahe.gldriver.net.RxHttpCallBack
import com.dahe.gldriver.ui.account.authperson.EditDriverActivity
import com.dahe.gldriver.ui.account.authperson.EditDrivingActivity
import com.dahe.gldriver.ui.account.authperson.EditPersonActivity
import com.dahe.gldriver.ui.account.authperson.EditQualificationActivity
import com.dahe.gldriver.ui.account.authperson.EditRoadActivity
import com.dahe.gldriver.ui.account.authperson.EditTrailerActivity
import com.dahe.gldriver.utils.SPUtils
import com.dahe.glex.bean.UserDetail
import com.dahe.mylibrary.base.BaseActivity
import com.dahe.mylibrary.net.CommonResponseBean
import com.dahe.mylibrary.utils.ActivityUtils
import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers
import io.reactivex.rxjava3.schedulers.Schedulers

/**
 * @ClassName CarDetailActivity
 * @Author john
 * @Date 2024/3/21 11:24
 * @Description 车辆详情
 */
class CarDetailActivity : BaseActivity<ActivityCarDetailBinding>(), View.OnClickListener {


    lateinit var CarDetail: CarDetail
    override fun initView(savedInstanceState: Bundle?) {
        setStatusHeightParams(binding.rlTop)
        setTitleBar("车辆详情", true)
        binding.run {
            circleBarView2.run {
                text = "完成度"
                unitText = "%"
                progress = 0
            }

            btnId.setOnClickListener(this@CarDetailActivity)
            llAgainId.setOnClickListener(this@CarDetailActivity)
            llSeeId.setOnClickListener(this@CarDetailActivity)

            btnDriver.setOnClickListener(this@CarDetailActivity)
            llAgainDriver.setOnClickListener(this@CarDetailActivity)
            llSeeDriver.setOnClickListener(this@CarDetailActivity)


            btnQua.setOnClickListener(this@CarDetailActivity)
            llAgainQua.setOnClickListener(this@CarDetailActivity)
            llSeeQua.setOnClickListener(this@CarDetailActivity)
        }
    }

    override fun onClick(view: View?) {
        super.onClick(view)
        if (!::CarDetail.isInitialized) {
            showToast("车辆信息未查到")
            return
        }

        binding.run {
            when (view?.id) {
                btnId.id, llAgainId.id -> ActivityUtils.startActivityForResult(
                    this@CarDetailActivity,
                    EditDrivingActivity::class.java, Bundle().apply {
                        putString(AppConfig.CAR_ID, CarDetail.vehicleNum)
                    }, 1
                )

                llSeeId.id -> ActivityUtils.startActivity(
                    mContext,
                    EditDrivingActivity::class.java,
                    Bundle().apply {
                        putBoolean(AppConfig.IS_ONLY_SHOW, true)
                        putString(AppConfig.CAR_ID, CarDetail.vehicleNum)
                    })

                btnDriver.id, llAgainDriver.id -> ActivityUtils.startActivityForResult(
                    this@CarDetailActivity,
                    EditTrailerActivity::class.java, Bundle().apply {
                        putString(AppConfig.CAR_ID, CarDetail.trailerVehicleNum)
                    }, 1
                )

                llSeeDriver.id -> ActivityUtils.startActivity(
                    mContext,
                    EditTrailerActivity::class.java,
                    Bundle().apply {
                        putBoolean(AppConfig.IS_ONLY_SHOW, true)
                        putString(AppConfig.CAR_ID, CarDetail.trailerVehicleNum)
                    })

                btnQua.id, llAgainQua.id -> ActivityUtils.startActivityForResult(
                    this@CarDetailActivity,
                    EditRoadActivity::class.java, Bundle().apply {
                        putString(AppConfig.CAR_ID, CarDetail.vehicleNum)
                    }, 1
                )

                llSeeQua.id -> ActivityUtils.startActivity(
                    mContext,
                    EditRoadActivity::class.java,
                    Bundle().apply {
                        putBoolean(AppConfig.IS_ONLY_SHOW, true)
                        putString(AppConfig.CAR_ID, CarDetail.vehicleNum)
                    })
            }
        }
    }

    override fun initDate() {
        var carId = intent.extras?.getString(AppConfig.CAR_ID).toString()
        DataManager.getInstance().getCarDocIntegrity(carId)
            .subscribeOn(Schedulers.io()).observeOn(AndroidSchedulers.mainThread())
            .subscribe(BaseObserver(mContext, object : RxHttpCallBack<CarDetail>() {
                override fun onSuccess(t: CommonResponseBean<CarDetail>) {
                    super.onSuccess(t)
                    initViewByData(t.data)
                }
            }))
    }

    private fun initViewByData(data: CarDetail) {
        var doneInfoCount = 0
        CarDetail = data
        binding.run {
            var missInfo = ""

            if (data.vehicleNum.isNullOrEmpty()) {
                tvInfo.text = "证件缺失将无法进行接单"
                missInfo.plus("行驶证、")
            } else {
                doneInfoCount++
                tvInfo.text = """${data.vehicleNum} ${data.vehicleType}"""
            }
            if (data.trailerVehicleNum.isNullOrEmpty()) {
                tvDriverInfo.text = "证件缺失将无法进行接单"
                missInfo.plus("挂车行驶证、")
            } else {
                doneInfoCount++
                tvDriverInfo.text = """${data.trailerVehicleNum} ${data.trailerVehicleType}"""
            }
            if (data.roadLicense.isNullOrEmpty()) {
                tvQualiInfo.text = "证件缺失将无法进行接单"
                missInfo.plus("道路运输许可证、")
            } else {
                doneInfoCount++
                tvQualiInfo.text = """${data.roadLicense}"""
            }


            btnNext.text = if (doneInfoCount == 3) "已完成" else "继续认证"
            tvContent.text = if (missInfo.isNullOrEmpty()) "认证成功,请接单把!!!" else missInfo


            llId.visibility = if (data.vehicleNum.isNullOrEmpty()) View.GONE else View.VISIBLE
            btnId.visibility = if (data.vehicleNum.isNullOrEmpty()) View.VISIBLE else View.GONE

            llDriver.visibility =
                if (data.trailerVehicleNum.isNullOrEmpty()) View.GONE else View.VISIBLE
            btnDriver.visibility =
                if (data.trailerVehicleNum.isNullOrEmpty()) View.VISIBLE else View.GONE
            llQua.visibility =
                if (data.roadLicense.isNullOrEmpty()) View.GONE else View.VISIBLE
            btnQua.visibility =
                if (data.roadLicense.isNullOrEmpty()) View.VISIBLE else View.GONE

            circleBarView2.progress = doneInfoCount * 100 / 3

        }
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        super.onActivityResult(requestCode, resultCode, data)
        if (resultCode == RESULT_OK && requestCode == 1) {
            initDate()
        }
    }
}